@@ -385,6 +385,7 @@ def save_imagename(work_dir, config):
 def get_coverage_env_variables(config):
     coverage_info = {
         "COVERAGE_RCFILE": "%(coverage_reports)s/.coveragerc" % config,
+        "COVERAGE_EXTRACSSFILE": "%(coverage_reports)s/.coverage.css" % config,
         "COVERAGE_FILE": "%(coverage_reports)s/.coverage_%(ci_job_name)s" % config,
         "COVERAGE_HOME": "/home/odoo/instance/extra_addons/%(ci_project_name)s" % config,
         "COVERAGE_CONTEXT": "job_%(ci_job_name)s" % config,
@@ -626,6 +627,8 @@ def prepare_coverage(config):
     fcoveragerc = path.join(config.get('container_vol'), '.coveragerc')
     with open(fcoveragerc, "w") as f_coveragerc:
         f_coveragerc.write(get_coverage_content(config))
+    copy(path.join(path.abspath(path.dirname(__file__)), "templates", "coverage.css"),
+         path.join(config.get('container_vol'), '.coverage.css'))
 
     _logger.debug('Create workdir %s', exec_cmd(config['container_name'], 'mkdir -p {coverage_reports}'.format(**config), user='odoo'))
 
